pub enum SearchStep {
Match(usize, usize),
Reject(usize, usize),
Done,
}Result of calling Searcher::next() or ReverseSearcher::next_back().
Variants
Match | Expresses that a match of the pattern has been found at
haystack[a..b].
|
Reject | Expresses that haystack[a..b] has been rejected as a possible match
of the pattern.
Note that there might be more than one Reject between two Matches,
there is no requirement for them to be combined into one.
|
Done | Expresses that every byte of the haystack has been visted, ending
the iteration.
|